### RLBot

more_vert Install missing python package Reset match settings Edit appearance config file
Install Package Package Name Install Package Close
Player Types
add Load more player types Download Bot Pack cloud_download Start Your Own Bot! create Load Folder folder_open Load Cfg File file_copy settings Manage bot folders
searchFilter
Toggle which team gets bots when you click them
Blue Team
{{ bot.name }} close
Orange Team
{{ bot.name }} close
Match Settings
Map {{map}}
Mode {{mode}}
Mutators Extra loop Hot-reload python bots Start Match Stop
Extra Options Skip Replays Instant Start Enable lockstep Close Mutators
Reset Defaults Close {{snackbarContent}} Bot Pack update available! Download close {{activeBot.name}}

Developers: {{activeBot.info.developer}}

Description: {{activeBot.info.description}}

Fun Fact: {{activeBot.info.fun_fact}}

GitHub: {{activeBot.info.github}}

Language: {{activeBot.info.language}}

{{activeBot.path}}

palette Edit Appearance folder Show Files Close Compatibility Warning

{{activeBot.name}} requires Java and it looks like you don't have it installed!

To play with it, you'll need to:

1. Download Java from java.com
2. Install it
3. Reboot your computer

This bot requires Google Chrome for its auto-run feature, and it looks like you don't have it installed! You can download it here.

Close Create New Bot Bot Name
Python Scratch
Begin Close Folder Settings {{path}} close {{path}} close Apply Close Downloading Bot Pack
cloud_download

{{ downloadStatus }}

Appearance loadout of {{ activeBot.name }} {{ appearanceEditor.path }} close

{{ colorType.name }} edit

remove_red_eye View blue car in game remove_red_eye View orange car in game check Save and close clear Revert changes